% --- Source file: GOFR.Rd ---
\name{GOFR}
\alias{GOFR}
\title{GOFR}
\description{
  Goodness-Of-Fit tests for binary Risk models (GOFR).
}
\usage{
GOFR(formula, data, link="logit", grid=c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9), 
     n_simulations, tol=10^-5, covariate=NULL)
}
\arguments{
  \item{formula}{A symbolic description of the model to be fitted. 
                  When there are covariates, one needs to include the covariates using +. For example,  formula should be in the following form response~risk_factor_1+...+risk_factor_p+covariate_1+...+covariate_q when the model is as follows:  the risk is additive with respect to risk factors as many as p and
one needs to adjust covariates as many as q.  }
  \item{data}{A data frame containing the variables in the model. }
  \item{link}{"logit" or "identity" to describe the link function to be used in the model. 
           The default is "logit".}
  \item{grid}{Vector of risk percentiles to be used as grid points for evaluation of the test-statistics. 
         Default is the vector of deciles  (see Details).}
  \item{n_simulations}{The number of simulations to compute p-value of the 
               Tail-Based Max-test-statistic (see Details). }
  \item{tol}{The convergence tolerance for fitting the model in the identity scale. The default is 10^-5. }
  \item{covariate}{The names of (categorical) variables which affect disease risk but are not used for 
                   constructing a risk prediction model. 
                   When the variables are specified as covariate, the odds ratio of risk factors is assumed to be 
                 homogeneous across the configurations of covariates. The default is NULL. }
}
\value{ A list with the following objects:
  \itemize{
    \item{\code{coefficients}}{ A named vector of coefficients which are the maximum likelihood estimates of the 
         regression parameters of the specified model}
    \item{\code{fitted.values}}{ A vector of fitted probabilities for the subjects in the data}
    \item{\code{cov}}{ Estimates of variance-covariance matrix of the coefficients} 
    \item{\code{TBM_ts}}{ The test-statistic for the TBM method}
    \item{\code{TBM_pv}}{ P-value for the TMB method}
    \item{\code{Windmeijer_ts}}{ The test statistic for the Windmeijer method} 
    \item{\code{Windmeijer_pv}}{ P-value for the Windmeijer method}
    \item{\code{HL_ts}}{ The test statistic for Hosmer-Lemeshow  method}
    \item{\code{HL_pv}}{ P-value for Hosmer-Lemeshow method}
  } % END: itemize
 }

\details{  
The procedure implements three alternative goodness-of-fit tests. 
The \bold{Hosmer-Lemeshow (HL)} test-statistic, which is based on observed vs expected event counts at group level, 
is implemented by categorizing subjects based on deciles of risk-distribution.  
The \bold{Windmeijer} test-statistic is defined by sum of individual level model residuals over all subjects. 
The third procedure implements a \bold{Tail-Based Max}-test-statistic \bold{(TBM)},  
where different tail-based (TB) test-statistics are first formed by summing model residuals over only 
those subjects which reach certain upper or lower risk-thresholds and then maximizing those statistics 
over different risk-thresholds.  
For example, if grid=(0.20,0.40,0.60,0.80), the \bold{TBM} procedure uses two regions at the upper tail of the 
risk distribution (ie > 80th percentile and >60th percentile ) and two regions at the lower tail of the 
risk distribution (ie < 20th percentile and <40th percentile ).  
A TB statistic is evaluated for each of the four one-sided tail regions and also for the four combinations 
of the upper- and lower-tail risk-regions. In addition, a TB statistic is always evaluated using all 
subjects as it corresponds to union of the upper and lower tail regions defined by the median value of the 
risk distribution. 
The \bold{TBM} statistic is then obtained by maximizing over nine different TB-statistics. 
If grid=(0.25,0.50,0.75), the \bold{TBM} procedure uses one region at the upper tail of the risk distribution 
(ie >75th percentile ) and one region at the lower tail of the risk distribution (ie < 25th percentile  ).  
A TB statistics is evaluated for each of the two one-sided tail regions and also for the one combination of 
the upper- and lower-tail risk-regions. 
In addition, the TB statistic is also evaluated using all subjects. 
Thus, in this case, the \bold{TBM} statistic is obtained by maximizing over four different TB-statistics. 
 To compute the p-value, we generate a multivariate Gaussian random variable from the covariance of the 
normalized TB statistics and mean of zero and obtain the maximum of the absolute values of the multivariate 
realization generated from the normal distribution. 
We then repeat the process as many as \code{n_simulations} and the p-value would be the ratio of the cases where 
the maxima from the simulations are larger than or equal to the maximum of the normalized TB statistics. 
The fitting of model under the identity link is done under a logistic representation of the identity-link 
function that assumes the disease is rare in the underlying population (see the reference by Song et al. for details).   
} % END: details

\references{ 
Song M, Kraft P, Joshi A D, Barrdahl M, and Chatterjee N (2014) Testing calibration of risk models at 
extremens of disease-risk, Biostatistics. \cr \cr
Hosmer D W and Lemeshow S (2000) Applied logistic regression. New York : John Wiley & Sons. \cr \cr
Windmeijer, F A G (1990) The asymptotic distribution of the sum of weighted squared residuals in binary choice models, 
Statistica Neerlandica 44(2), 69-78. 
}
%\author{Han Zhang and Kai Yu }
\seealso{ \code{\link{getSummary}} }
\examples{

# Example 1  : Use simulated dataset which was generated under an "alternative" model that is in 
# between additive and multiplicative model (see Song et al., 2013)  

data(Xdata1,package="CBRM")

## Fit under the multiplicative model 
fit_multiplicative<-GOFR(case.control~SNP1+SNP2+SNP3+SNP4+SNP5+SNP6+SNP7+SNP8+SNP9+SNP10,
      data=Xdata1, link="logit", grid=c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9), n_simulations=10000)

## Compute a summary table for the analysis under the multiplicative model
getSummary(fit_multiplicative)

## Fit under the additive model 
fit_additive<-GOFR(case.control~SNP1+SNP2+SNP3+SNP4+SNP5+SNP6+SNP7+SNP8+SNP9+SNP10,data=Xdata1, 
    link="identity", grid=c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9),n_simulations=10000, tol=10^-5)

## Compute a summary table for the analysis under the additive model  
getSummary(fit_additive)

## Example 2 : Data are generated assuming a logistic model for 10 SNPs where  4 of the SNPs have 
##  pair-wise interactions. The main effect is log(1.05) and the interaction effect is log(1.1). 
data(Xdata2,package="CBRM")

## Fit under the model without interaction 
fit_without_interactions<-GOFR(case.control~SNP1+SNP2+SNP3+SNP4+SNP5+SNP6+SNP7+SNP8+SNP9+SNP10,
   data=Xdata2, link="logit", grid=c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9), n_simulations=10000)

## Compute a summary table for the analysis under the model without  interaction
getSummary(fit_without_interactions)


## Now fit  the model with correct interaction terms included ##
fit_with_interactions<-GOFR(case.control~SNP1+SNP2+SNP3+SNP4+SNP5+SNP6+SNP7+SNP8+SNP9+SNP10+
                            SNP1:SNP2+SNP1:SNP3+SNP1:SNP4+SNP2:SNP3+SNP2:SNP4+SNP3:SNP4,
                 data=Xdata2, link="logit", grid=c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9), 
                 n_simulations=10000)

## Compute a summary table for the analysis under the model with interaction among 4 SNPs
getSummary(fit_with_interactions)

}

\keyword{model} 

